# MossNet
MossNet is a Python package for performing network analyses on MOSS results.

## Installation
MossNet can be installed using `pip`:

```bash
sudo pip install mossnet
```

If you are using a machine on which you lack administrative powers, MossNet can be installed locally using `pip`:

```bash
pip install --user mossnet
```

## Usage
TODO

Full documentation can be found at [https://niemasd.github.io/MossNet/](https://niemasd.github.io/MossNet/), and more examples can be found in the [MossNet Wiki](https://github.com/niemasd/MossNet/wiki).
